@@ -74,7 +74,7 @@ class Exceptions:
 
 class MediaPackageClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/mediapackage.html#MediaPackage.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/mediapackage.html#MediaPackage.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html)
     """
 
@@ -90,7 +90,7 @@ class MediaPackageClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/mediapackage.html#MediaPackage.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/mediapackage.html#MediaPackage.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#can_paginate)
         """
 
@@ -98,8 +98,8 @@ class MediaPackageClient(BaseClient):
         self,
         *,
         Id: str,
-        EgressAccessLogs: "EgressAccessLogsTypeDef" = None,
-        IngressAccessLogs: "IngressAccessLogsTypeDef" = None
+        EgressAccessLogs: "EgressAccessLogsTypeDef" = ...,
+        IngressAccessLogs: "IngressAccessLogsTypeDef" = ...
     ) -> ConfigureLogsResponseTypeDef:
         """
         Changes the Channel's properities to configure log subscription See also: `AWS
@@ -107,17 +107,17 @@ class MediaPackageClient(BaseClient):
         12/ConfigureLogs>`_ **Request Syntax** response = client.configure_logs(
         EgressAccessLogs={ 'LogGroupName': 'str...
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/mediapackage.html#MediaPackage.Client.configure_logs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/mediapackage.html#MediaPackage.Client.configure_logs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#configure_logs)
         """
 
     def create_channel(
-        self, *, Id: str, Description: str = None, Tags: Mapping[str, str] = None
+        self, *, Id: str, Description: str = ..., Tags: Mapping[str, str] = ...
     ) -> CreateChannelResponseTypeDef:
         """
         Creates a new Channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/mediapackage.html#MediaPackage.Client.create_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/mediapackage.html#MediaPackage.Client.create_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#create_channel)
         """
 
@@ -133,7 +133,7 @@ class MediaPackageClient(BaseClient):
         """
         Creates a new HarvestJob record.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/mediapackage.html#MediaPackage.Client.create_harvest_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/mediapackage.html#MediaPackage.Client.create_harvest_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#create_harvest_job)
         """
 
@@ -142,23 +142,23 @@ class MediaPackageClient(BaseClient):
         *,
         ChannelId: str,
         Id: str,
-        Authorization: "AuthorizationTypeDef" = None,
-        CmafPackage: "CmafPackageCreateOrUpdateParametersTypeDef" = None,
-        DashPackage: "DashPackageTypeDef" = None,
-        Description: str = None,
-        HlsPackage: "HlsPackageTypeDef" = None,
-        ManifestName: str = None,
-        MssPackage: "MssPackageTypeDef" = None,
-        Origination: OriginationType = None,
-        StartoverWindowSeconds: int = None,
-        Tags: Mapping[str, str] = None,
-        TimeDelaySeconds: int = None,
-        Whitelist: Sequence[str] = None
+        Authorization: "AuthorizationTypeDef" = ...,
+        CmafPackage: "CmafPackageCreateOrUpdateParametersTypeDef" = ...,
+        DashPackage: "DashPackageTypeDef" = ...,
+        Description: str = ...,
+        HlsPackage: "HlsPackageTypeDef" = ...,
+        ManifestName: str = ...,
+        MssPackage: "MssPackageTypeDef" = ...,
+        Origination: OriginationType = ...,
+        StartoverWindowSeconds: int = ...,
+        Tags: Mapping[str, str] = ...,
+        TimeDelaySeconds: int = ...,
+        Whitelist: Sequence[str] = ...
     ) -> CreateOriginEndpointResponseTypeDef:
         """
         Creates a new OriginEndpoint record.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/mediapackage.html#MediaPackage.Client.create_origin_endpoint)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/mediapackage.html#MediaPackage.Client.create_origin_endpoint)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#create_origin_endpoint)
         """
 
@@ -166,7 +166,7 @@ class MediaPackageClient(BaseClient):
         """
         Deletes an existing Channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/mediapackage.html#MediaPackage.Client.delete_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/mediapackage.html#MediaPackage.Client.delete_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#delete_channel)
         """
 
@@ -174,7 +174,7 @@ class MediaPackageClient(BaseClient):
         """
         Deletes an existing OriginEndpoint.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/mediapackage.html#MediaPackage.Client.delete_origin_endpoint)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/mediapackage.html#MediaPackage.Client.delete_origin_endpoint)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#delete_origin_endpoint)
         """
 
@@ -182,7 +182,7 @@ class MediaPackageClient(BaseClient):
         """
         Gets details about a Channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/mediapackage.html#MediaPackage.Client.describe_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/mediapackage.html#MediaPackage.Client.describe_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#describe_channel)
         """
 
@@ -190,7 +190,7 @@ class MediaPackageClient(BaseClient):
         """
         Gets details about an existing HarvestJob.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/mediapackage.html#MediaPackage.Client.describe_harvest_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/mediapackage.html#MediaPackage.Client.describe_harvest_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#describe_harvest_job)
         """
 
@@ -198,56 +198,56 @@ class MediaPackageClient(BaseClient):
         """
         Gets details about an existing OriginEndpoint.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/mediapackage.html#MediaPackage.Client.describe_origin_endpoint)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/mediapackage.html#MediaPackage.Client.describe_origin_endpoint)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#describe_origin_endpoint)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/mediapackage.html#MediaPackage.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/mediapackage.html#MediaPackage.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#generate_presigned_url)
         """
 
     def list_channels(
-        self, *, MaxResults: int = None, NextToken: str = None
+        self, *, MaxResults: int = ..., NextToken: str = ...
     ) -> ListChannelsResponseTypeDef:
         """
         Returns a collection of Channels.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/mediapackage.html#MediaPackage.Client.list_channels)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/mediapackage.html#MediaPackage.Client.list_channels)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#list_channels)
         """
 
     def list_harvest_jobs(
         self,
         *,
-        IncludeChannelId: str = None,
-        IncludeStatus: str = None,
-        MaxResults: int = None,
-        NextToken: str = None
+        IncludeChannelId: str = ...,
+        IncludeStatus: str = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...
     ) -> ListHarvestJobsResponseTypeDef:
         """
         Returns a collection of HarvestJob records.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/mediapackage.html#MediaPackage.Client.list_harvest_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/mediapackage.html#MediaPackage.Client.list_harvest_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#list_harvest_jobs)
         """
 
     def list_origin_endpoints(
-        self, *, ChannelId: str = None, MaxResults: int = None, NextToken: str = None
+        self, *, ChannelId: str = ..., MaxResults: int = ..., NextToken: str = ...
     ) -> ListOriginEndpointsResponseTypeDef:
         """
         Returns a collection of OriginEndpoint records.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/mediapackage.html#MediaPackage.Client.list_origin_endpoints)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/mediapackage.html#MediaPackage.Client.list_origin_endpoints)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#list_origin_endpoints)
         """
 
@@ -257,7 +257,7 @@ class MediaPackageClient(BaseClient):
         ackage-2017-10-12/ListTagsForResource>`_ **Request Syntax** response =
         client.list_tags_for_resource( ResourceArn='string' ).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/mediapackage.html#MediaPackage.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/mediapackage.html#MediaPackage.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#list_tags_for_resource)
         """
 
@@ -265,7 +265,7 @@ class MediaPackageClient(BaseClient):
         """
         Changes the Channel's first IngestEndpoint's username and password.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/mediapackage.html#MediaPackage.Client.rotate_channel_credentials)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/mediapackage.html#MediaPackage.Client.rotate_channel_credentials)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#rotate_channel_credentials)
         """
 
@@ -276,7 +276,7 @@ class MediaPackageClient(BaseClient):
         Rotate the IngestEndpoint's username and password, as specified by the
         IngestEndpoint's id.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/mediapackage.html#MediaPackage.Client.rotate_ingest_endpoint_credentials)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/mediapackage.html#MediaPackage.Client.rotate_ingest_endpoint_credentials)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#rotate_ingest_endpoint_credentials)
         """
 
@@ -287,7 +287,7 @@ class MediaPackageClient(BaseClient):
         **Request Syntax** response = client.tag_resource( ResourceArn='string', Tags={
         'string': 'string' } ).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/mediapackage.html#MediaPackage.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/mediapackage.html#MediaPackage.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#tag_resource)
         """
 
@@ -297,15 +297,15 @@ class MediaPackageClient(BaseClient):
         ackage-2017-10-12/UntagResource>`_ **Request Syntax** response =
         client.untag_resource( ResourceArn='string', TagKeys=[ 'string', ] ).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/mediapackage.html#MediaPackage.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/mediapackage.html#MediaPackage.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#untag_resource)
         """
 
-    def update_channel(self, *, Id: str, Description: str = None) -> UpdateChannelResponseTypeDef:
+    def update_channel(self, *, Id: str, Description: str = ...) -> UpdateChannelResponseTypeDef:
         """
         Updates an existing Channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/mediapackage.html#MediaPackage.Client.update_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/mediapackage.html#MediaPackage.Client.update_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#update_channel)
         """
 
@@ -313,29 +313,29 @@ class MediaPackageClient(BaseClient):
         self,
         *,
         Id: str,
-        Authorization: "AuthorizationTypeDef" = None,
-        CmafPackage: "CmafPackageCreateOrUpdateParametersTypeDef" = None,
-        DashPackage: "DashPackageTypeDef" = None,
-        Description: str = None,
-        HlsPackage: "HlsPackageTypeDef" = None,
-        ManifestName: str = None,
-        MssPackage: "MssPackageTypeDef" = None,
-        Origination: OriginationType = None,
-        StartoverWindowSeconds: int = None,
-        TimeDelaySeconds: int = None,
-        Whitelist: Sequence[str] = None
+        Authorization: "AuthorizationTypeDef" = ...,
+        CmafPackage: "CmafPackageCreateOrUpdateParametersTypeDef" = ...,
+        DashPackage: "DashPackageTypeDef" = ...,
+        Description: str = ...,
+        HlsPackage: "HlsPackageTypeDef" = ...,
+        ManifestName: str = ...,
+        MssPackage: "MssPackageTypeDef" = ...,
+        Origination: OriginationType = ...,
+        StartoverWindowSeconds: int = ...,
+        TimeDelaySeconds: int = ...,
+        Whitelist: Sequence[str] = ...
     ) -> UpdateOriginEndpointResponseTypeDef:
         """
         Updates an existing OriginEndpoint.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/mediapackage.html#MediaPackage.Client.update_origin_endpoint)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/mediapackage.html#MediaPackage.Client.update_origin_endpoint)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#update_origin_endpoint)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_channels"]) -> ListChannelsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/mediapackage.html#MediaPackage.Paginator.ListChannels)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/mediapackage.html#MediaPackage.Paginator.ListChannels)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/paginators.html#listchannelspaginator)
         """
 
@@ -344,7 +344,7 @@ class MediaPackageClient(BaseClient):
         self, operation_name: Literal["list_harvest_jobs"]
     ) -> ListHarvestJobsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/mediapackage.html#MediaPackage.Paginator.ListHarvestJobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/mediapackage.html#MediaPackage.Paginator.ListHarvestJobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/paginators.html#listharvestjobspaginator)
         """
 
@@ -353,6 +353,6 @@ class MediaPackageClient(BaseClient):
         self, operation_name: Literal["list_origin_endpoints"]
     ) -> ListOriginEndpointsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/mediapackage.html#MediaPackage.Paginator.ListOriginEndpoints)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/mediapackage.html#MediaPackage.Paginator.ListOriginEndpoints)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/paginators.html#listoriginendpointspaginator)
         """
